<?php
/**
 * Plugin Name: Stripe Payments Country Autodetect
 * Plugin URI: https://s-plugins.com/
 * Description: Autodetect Customer Country
 * Version: 1.0.1
 * Author: Tips and Tricks HQ, alexanderfoxc
 * Author URI: https://s-plugins.com/
 * License: GPL2
 * Text Domain: asp-country-autodetect
 * Domain Path: /languages
 */

namespace Accept_Stripe_Payments\Country_Detect;

if ( ! defined( 'ABSPATH' ) ) {
	exit; //Exit if accessed directly
}

class Main {

	public $helper;
	public $asp_main;
	public $file               = __FILE__;
	public $textdomain         = 'asp-country-autodetect';
	public $ADDON_SHORT_NAME   = 'countrydetect';
	public $ADDON_FULL_NAME    = 'Stripe Payments Country Autodetect';
	public $MIN_ASP_VER        = '2.0.12';
	public $SLUG               = 'stripe-payments-country-autodetect';
	public $SETTINGS_TAB_NAME  = 'countrydetect';
	public $enabled            = false;
	protected static $instance = null;

	const ADDON_VER  = '1.0.1';
	const ADDON_NAME = 'Country Autodetect';

	private $curl_error = false;

	public function __construct() {
		add_action( 'plugins_loaded', array( $this, 'plugins_loaded' ) );
		add_filter( 'asp_ng_pp_default_country_override', array( $this, 'detect_country' ) );
	}

	public static function get_instance() {

		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	public function plugins_loaded() {
		if ( class_exists( 'AcceptStripePayments' ) ) {
			$this->asp_main = \AcceptStripePayments::get_instance();
			$this->helper   = new \ASPAddonsHelper( $this );
			//check minimum required core plugin version
			if ( ! $this->helper->check_ver() ) {
				return false;
			}
			$this->helper->init_tasks();

			$this->enabled = $this->asp_main->get_setting( 'country_autodetect_enable' );

			if ( is_admin() ) {
				require_once plugin_dir_path( __FILE__ ) . 'admin/class-admin.php';
				new Admin( $this->helper );
			}
		}
	}

	private function locate( $ip ) {
		$url = sprintf( 'http://www.geoplugin.net/json.gp?ip=%s', $ip );

		if ( function_exists( 'curl_init' ) ) {

			$ch = curl_init();
			curl_setopt( $ch, CURLOPT_URL, $url );
			curl_setopt( $ch, CURLOPT_RETURNTRANSFER, 1 );
			curl_setopt( $ch, CURLOPT_USERAGENT, 'geoPlugin PHP Class v1.1' );
			curl_setopt( $ch, CURLOPT_FAILONERROR, true );
			curl_setopt( $ch, CURLOPT_TIMEOUT, 3 );

			$response = curl_exec( $ch );

			if ( curl_errno( $ch ) ) {
				$this->curl_error = curl_error( $ch );
			}

			curl_close( $ch );

		} else {
			$this->curl_error = true;
		}

		if ( false !== $this->curl_error ) {
			return null;
		}

		$res = json_decode( $response );

		if ( isset( $res->geoplugin_countryCode ) ) {
			return $res->geoplugin_countryCode;
		}

		return null;
	}

	public function detect_country( $country ) {

		if ( ! $this->enabled ) {
			return $country;
		}

		if ( ! empty( $country ) ) {
			return $country;
		}

		$ip = ! empty( $_SERVER['REMOTE_ADDR'] ) ? $_SERVER['REMOTE_ADDR'] : false;

		if ( false === $ip ) {
			return $country;
		}

		$cached = false;

		//check if country code is available in cache
		$cached = get_transient( 'wp_asp_country_autodetect_ip_' . $ip );

		if ( false !== $cached ) {
			return $cached;
		} else {
			$country_code = $this->locate( $ip );

			if ( ! empty( $country_code ) ) {
				$country = $country_code;
				//cache country code for 30 minutes
				set_transient( 'wp_asp_country_autodetect_ip_' . $ip, $country, 0.5 * HOUR_IN_SECONDS );
			}
		}

		return $country;
	}

}

new Main();
